VideoEffectSkinTone class

A skin-tone preset (dual-LUT grade: a skin LUT applied over skin regions, a background LUT elsewhere; from a third-party beauty-effects SkinColorResources set). Both LUTs are 512² square LUTs.

Constructors

VideoEffectSkinTone(String key, String label, String skinAsset, String bgAsset)
const

Properties

bgAsset String
final
hashCode int
The hash code for this object.
no setterinherited
key String
final
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skinAsset String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited